
								***** COUNTRY CODES

* List of countries present in imports or exports

use iso2 using $base/base_export.dta, clear 

duplicates drop
save $tmp/country_list, replace

 
* merge with iso2-iso3 correspondence table

insheet using $base/countrycodes.csv, clear
drop if _n==1
rename v2 iso3
rename v1 iso2
merge 1:1 iso2 using $tmp/country_list
replace iso3="BEL" if iso3=="LUX" // Luxembourg in Belgium
replace iso3="BEL" if iso2=="XU" // Lux+Bel as Belgium
replace iso3="SRB" if iso2=="CS" | iso2=="ME" | iso2=="XK" | iso2=="XM" ///
| iso2=="XS" | iso2=="YU"| iso2=="XN" //ex-Yougoslavia
replace iso3="TMP" if iso2=="TP" // Yimor Oriental
drop _merge
drop if iso3==""

*drop DOM/TOM
*Mayotte
drop if iso3=="MYT"
*French Polynesia
drop if iso3=="PYF"
drop if iso3=="GUF"
drop if iso3=="REU"
drop if iso3=="MAF"
drop if iso3=="SPM"
drop if iso3=="ATF"
drop if iso3=="FRA"
drop if iso3=="GLP"
drop if iso3=="MTQ"
*new caledonia
drop if iso3=="NCL"
*wallis and futuna
drop if iso3=="WLF"
drop if iso3=="BLM"
		
save $tmp/country_list.dta, replace
		
		
		

								***** PREPARE EXPORTS

		
		
use  $base/base_export.dta, clear 
		
merge m:1 iso2 using $tmp/country_list.dta
keep if _merge==3
						
collapse (sum) export qty usup, by(year siren nc8 iso3)

bys siren nc8 iso3: egen min_year=min(year)

drop if year<1997
gen present1996=(min_year<=1996)
drop min_year
		
tostring siren, gen(tmp)
gen test=(length(tmp)==9)

forvalues i=1/9{
	gen position`i'=substr(tmp,10-`i',1) if test==1
	destring position`i', replace
}

replace position2=2*position2
replace position4=2*position4
replace position6=2*position6
replace position8=2*position8
		
forvalues i=2(2)8 {
	replace position`i'=position`i'-10+1 if position`i'>=10 & position`i'!=.
}
		
gen sum=(position1+position2+position3+position4+position5+position6+position7+position8+position9)/10 
gen int_sum=int(sum)
gen test2=(sum-int_sum==0)
		
drop if test2==0 | test==0
drop test test2 position* tmp sum int_sum



rename nc8 cn8
merge m:1 cn8 year using $base/cn8_cn8plus_1997_2010.dta, keepusing(cn8 cn8plus)
keep if _merge==3
drop _merge	

save $tmp/export_cn8plus.dta, replace


				****Clean exports


***I decide that cn8plus with more than 80% of usup are using usup rather than weight
gen usup_yes=(usup!=0)
bys cn8plus: egen mean_usup=mean(usup_yes)
gen nc8_usup=(mean_usup>.8)

collapse (sum) export qty usup present1996 (mean) nc8_usup , by(siren iso3 year cn8plus)

***I compute the average ratio of qty and usup within a firm-cn8plus pair
gen ratio=qty/usup
replace ratio=. if ratio==0
bys siren cn8plus: egen mean_ratio=mean(ratio)

***I use this to infer missing quantities when I see one of them
replace qty=mean_ratio*usup if qty==0 & usup!=0 & mean_ratio!=0 & nc8_usup==0
replace usup=qty/mean_ratio if usup==0 & qty!=0 & mean_ratio!=0 & nc8_usup==1

***Create a new quantity that is usup and weight accordingly
gen new_qty=usup if nc8_usup==1 
replace new_qty=qty if nc8_usup==0
keep year siren iso3 export cn8plus new_qty present1996
rename new_qty qty
replace qty=0 if qty==.	


egen panel=group(siren cn8plus iso3)

bys panel (year): gen id_spell=1 if _n==1
bys panel (year): replace id_spell=id_spell[_n-1]+(year[_n-1]!=year-1) if id_spell==.

***	Cleaning of prices

gen price=export/qty
gen log_price=log(export/qty)

xtset panel year

gen price_diff=log_price-l.log_price

gen weird=1 if (price_diff>1 & price_diff!=.) | price_diff<-1|log_price==.
bys panel id_spell: egen flag=max(weird)
drop if flag==1


preserve

xtset panel year
gen log_export=log(export)
gen entry=(log_export!=. & l.log_export==. & year!=1997)
replace entry=1-(present1996>=1) if year==1997

keep siren iso3 cn8plus year entry
save $data/entry.dta, replace

restore

preserve

bys id_spell panel: egen length_spell=count(year)
drop if length_spell==1 

bys panel id_spell: egen min_year_spell=min(year)

keep siren min_year_spell
duplicates drop
save $data/first_year_spell.dta, replace	
restore

keep year siren cn8plus iso3 id_spell export qty


save $data/export_ready.dta, replace

								
							
					
					
								***** CONSTRUCTION EXCHANGE RATES

					
use $base/ex_rate.dta, clear

bys iso3: egen n_obs=count(real_exrate_norm)

replace real_exrate_norm=. if n_obs!=16

drop if n_obs!=16

gen log_rer=log(real_exrate_norm)
gen log_er=log(exrate_norm)

replace log_rer=log_er if log_rer==.

egen id_iso=group(iso3)
xtset id_iso year

gen t=year-1994
egen iso_g=group(iso3)

reg log_rer i.iso_g#c.t
predict log_rer_dev, r

gen l_log_rer_dev=l.log_rer_dev

keep year iso3 log_rer_dev l_log_rer_dev

save $tmp/exrate_instrufirm.dta, replace


					
								***** CONSTRUCTION IMPORT WEIGHTS
								
																
use  $base/base_import.dta, clear 
		
merge m:1 iso2 using $tmp/country_list.dta
keep if _merge==3
drop _merge	

drop if year<1997	

gen hs6=floor(nc8/100)

merge m:1 hs6 using $base/rauch_hs6.dta
drop if _merge==2
drop _merge
	
collapse (sum) import, by(year siren iso3 con)


rename year min_year_spell

merge m:1 siren min_year_spell using $data/first_year_spell.dta
keep if _merge==3
drop _merge

collapse (sum) import, by(siren iso3 min_year_spell con)

bys siren min_year_spell: egen sum_import=sum(import)
gen import_w0s=import/sum_import
keep if con=="n"
keep siren min_year_spell iso3 import_w0s


gen obs=2011-min_year_spell
expand obs
bys siren iso3 min_year_spell: gen year=min_year_spell-1+_n

drop obs

merge m:1 year iso3 using $tmp/exrate_instrufirm.dta
drop if _merge==2
drop _merge


gen rer_dev_w0s=import_w0s*log_rer_dev
gen l_rer_dev_w0s=import_w0s*l_log_rer_dev

collapse (sum) rer_dev_w0s l_rer_dev_w0s, by(year siren min_year_spell)

save $data/instru_w0s.dta, replace 





								***** CONSTRUCTION MARKET SHARES FROM BACI
						
		
		
***First, aggregate BACI table	at hs6plus level	
		
use $base/ex_rate.dta, clear

keep if iso3=="USA"
keep year exrate
rename exrate exrate_UStoEURO

tempfile exrate   
save `exrate'


use $base/geo_cepii.dta, clear
keep iso3 cnum
duplicates drop

tempfile iso3_cnum   
save `iso3_cnum'


use if t>1996 & t<2011 using $base/baci92_8915.dta, clear

collapse (sum) v, by(j t hs6)

rename j cnum
merge m:1 cnum using `iso3_cnum', keepusing(cnum iso3)
keep if _merge==3
drop _merge cnum
rename t year

replace iso3="BEL" if iso3=="LUX"
replace iso3 = "ROU" if iso3 == "ROM"
replace iso3 = "SRB" if iso3 == "YUG"

gen year_hs6=1992
rename year year_real
rename year_hs6 year
merge m:1 hs6 year using $base/hs6_hs6plus_1992_2010.dta, keepusing(hs6 hs6plus)
keep if _merge==3
drop _merge

drop year
rename year_real year

collapse (sum) v, by(year hs6plus iso3)

merge m:1 year using `exrate'
drop _merge
gen total_export_EURO=v*exrate_UStoEURO*1000

keep total_export_EURO year hs6plus iso3

save $tmp/baci_hs6plus.dta, replace


***Second, we need to assign cn8plus to a single hs6plus (not that easy)		
		

use export nc8 year using $base/base_export.dta if year>=1997 & year<=2010, clear 

collapse (sum) export, by(nc8 year)

rename nc8 cn8
merge m:1 cn8 year using $base/cn8_cn8plus_1997_2010
keep if _merge==3 
drop _merge

g hs6 = floor(cn8/100)
merge m:1 hs6 year using $base/hs6_hs6plus_1992_2010.dta


collapse (sum) export, by(cn8plus hs6plus)
egen total = sum(export), by(cn8plus)
g share = export/total
gsort cn8plus - share 	
bysort cn8plus : g count = _N  
bysort cn8plus : keep if _n==1
sum share, d	  
sum share if share < 0.99, d
keep if share < 0.99
keep cn8plus hs6plus	 
save $tmp/main_hs6plus_by_cn8plus.dta, replace


use $base/cn8_cn8plus_1997_2010, clear
g hs6 = floor(cn8/100)
merge m:1 hs6 year using $base/hs6_hs6plus_1992_2010
keep cn8plus hs6plus
duplicates drop
duplicates tag cn8plus, g(d)
merge 1:1 cn8plus hs6plus using $tmp/main_hs6plus_by_cn8plus.dta
drop if _merge == 1 & d>0
drop d
duplicates tag cn8plus, g(d)

keep cn8plus hs6plus
save  $data/cn8plus_to_hs6plus_1997_2010, replace
 

***Finally, we compute the market shares of all exporters		
 
use $tmp/export_cn8plus.dta, clear

merge m:1 cn8plus using $tmp/cn8plus_to_hs6plus_1997_2010
							
collapse (sum) export, by(iso3 hs6plus year siren)

egen panel=group(siren hs6plus iso3)

bys panel (year): gen id_spell=1 if _n==1
bys panel (year): replace id_spell=id_spell[_n-1]+(year[_n-1]!=year-1) if id_spell==.

bys panel id_spell: egen min_year_spell=min(year)
bys panel id_spell: egen max_year_spell=max(year)

replace iso3 = "COG" if iso3 == "COD"

merge m:1 iso3 year hs6plus using $tmp/baci_hs6plus.dta
keep if _merge == 3 
rename total_export_EURO sum_export

drop if min_year_spell==max_year_spell

gen ms=export/sum_export
g ms_nowinsor=ms
replace ms = 1 if ms>1

gen ms0s=ms if min_year_spell==year
bys siren hs6plus iso3 min_year_spell: egen ms0=mean(ms0s)

keep iso3 hs6plus year siren ms0
duplicates drop iso3 hs6plus year siren, force  /* the problem comes from CONGO which is duplicated because of country code issues */

save $data/meanms_byspell_BACI.dta, replace
						
						
						
						
												
								*****	CONSTRUCTION GDP CONTROLS
								
								
***Construct gdp controls

use $tmp/export_cn8plus.dta, clear

collapse (sum) export, by(siren year iso3)

merge m:1 iso3 using $base/gdp_capita.dta
keep if _merge==3
drop _merge

bys siren year: egen sum_export=sum(export)
gen gdp_w_export=export*log_gdp_capita/sum_export
collapse (sum) gdp_w_export, by(siren year)
save $tmp/gdp_export.dta, replace


use  $base/base_import.dta, clear 
		
merge m:1 iso2 using $tmp/country_list
keep if _merge==3
	
collapse (sum) import, by(siren year iso3)

merge m:1 iso3 using $base/gdp_capita.dta
keep if _merge==3
drop _merge

bys siren year: egen sum_import=sum(import)
gen gdp_w_import=import*log_gdp_capita/sum_import
collapse (sum) gdp_w_import, by(siren year)

merge 1:1 siren year using $tmp/gdp_export.dta
drop _merge
save $data/gdp_controls.dta, replace
							
							
							
									*****	CONSTRUCTION IMPORT RATIO BRN
			
use  $base/base_import.dta, clear 

collapse (sum) import, by(year siren)

merge 1:1 siren year using $base/brn_quality.dta

preserve

collapse (max) _merge, by(siren)

keep if _merge==1
drop _merge

save $tmp/once_importer_nerver_brn.dta, replace
restore

drop if _merge==1 
   
collapse (sum)  import sales cr_gf , by(siren) 
g ratio_costs=import/(1000*cr_gf)
g ratio_sales=import/(1000*sales)

replace ratio_costs=0 if ratio_costs==. & import==0 /*missing because total costs */
replace ratio_sales=0 if ratio_sales==. & import==0 /*missing because total costs */

foreach var of varlist ratio_* {
replace `var'=1 if `var'>1 & `var'!=.
replace `var'=0 if `var'<0
}

keep  siren  ratio_costs ratio_sales 

append using $tmp/once_importer_nerver_brn.dta

save $data/import_ratio_brn.dta, replace


							
								****Convert cn8plus into product
								
								
use $base/cn8_cn8plus_1997_2010.dta, clear

gen nc2=floor(cn8/1000000)

duplicates tag cn8plus nc2, gen(n_obs)
keep cn8plus nc2 n_obs
duplicates drop

bys cn8plus: egen max_obs=max(n_obs)
keep if max_obs==n_obs
keep cn8plus nc2

gen product=1 if nc2<=5
replace product=2 if nc2>=6 & nc2<=15
replace product=3 if nc2>=16 & nc2<=24
replace product=4 if nc2>=25 & nc2<=27
replace product=5 if nc2>=28 & nc2<=38
replace product=6 if nc2==39 | nc2==40
replace product=7 if nc2>=41 & nc2<=43
replace product=8 if nc2>=44 & nc2<=49
replace product=9 if nc2>=50 & nc2<=63
replace product=10 if nc2>=64 & nc2<=67
replace product=11 if nc2>=68 & nc2<=71
replace product=12 if nc2>=72 & nc2<=83
replace product=13 if nc2==84 | nc2==85
replace product=14 if nc2>=86 & nc2<=89
replace product=15 if nc2>=90 & nc2<=97
replace product=16 if nc2==98 | nc2==99 

keep cn8plus product
save $data/cn8plus_to_product.dta, replace  								
							
							
	

use $base/cn8_cn8plus_1997_2010.dta, clear
gen hs6=floor(cn8/100)
duplicates tag	cn8plus	hs6, gen(n_obs)
keep cn8plus hs6 n_obs
duplicates drop
bys cn8plus: egen max_obs=max(n_obs)
keep if	max_obs==n_obs
keep cn8plus hs6
duplicates drop cn8plus,force
save $data/hs6_cn8plus.dta, replace


	***Elasticity estimates from Soderberry

use $base/elast_LIMLhybrid_hs10.dta, clear		
destring good, replace
keep good sigma
duplicates drop


gen nc2=floor(good/100000000)
gen product=1 if nc2<=5
replace product=2 if nc2>=6 & nc2<=15
replace product=3 if nc2>=16 & nc2<=24
replace product=4 if nc2>=25 & nc2<=27
replace product=5 if nc2>=28 & nc2<=38
replace product=6 if nc2==39 | nc2==40
replace product=7 if nc2>=41 & nc2<=43
replace product=8 if nc2>=44 & nc2<=49
replace product=9 if nc2>=50 & nc2<=63
replace product=10 if nc2>=64 & nc2<=67
replace product=11 if nc2>=68 & nc2<=71
replace product=12 if nc2>=72 & nc2<=83
replace product=13 if nc2==84 | nc2==85
replace product=14 if nc2>=86 & nc2<=89
replace product=15 if nc2>=90 & nc2<=97
drop if product==.
tab product
collapse (mean) sigma_Anson=sigma, by(product)
save $data/Anson_hs1.dta, replace



	***We obtain quality ladders from Khandelwal (2010)


use $base/ladder_hs10_rep.dta, clear
drop sic87 init_value

gen hs6=floor(hs/10000)
collapse (mean) ladder_Khandelwal=ladder, by(hs6)	
save $data/ladder_Khandelwal_hs6.dta, replace


	***We obtain Sutton's measure


insheet using $base/hs_isic.csv, clear
rename isicr2 isic_rev2
merge m:1 isic_rev2 using $base/sutton_isic_rev2.dta
drop if sutton==.
keep hs6 sutton
duplicates drop
save $data/sutton_hs6.dta, replace

gen nc2=floor(hs6/10000)
gen product=1 if nc2<=5
replace product=2 if nc2>=6 & nc2<=15
replace product=3 if nc2>=16 & nc2<=24
replace product=4 if nc2>=25 & nc2<=27
replace product=5 if nc2>=28 & nc2<=38
replace product=6 if nc2==39 | nc2==40
replace product=7 if nc2>=41 & nc2<=43
replace product=8 if nc2>=44 & nc2<=49
replace product=9 if nc2>=50 & nc2<=63
replace product=10 if nc2>=64 & nc2<=67
replace product=11 if nc2>=68 & nc2<=71
replace product=12 if nc2>=72 & nc2<=83
replace product=13 if nc2==84 | nc2==85
replace product=14 if nc2>=86 & nc2<=89
replace product=15 if nc2>=90 & nc2<=97
drop if product==.
tab product
collapse (mean) sutton, by(product)
save $data/sutton_hs1.dta, replace


	***We obtain quality measures of Champagne
	
use $base/juhlin_all.dta, clear
keep juhlin_stars siren
drop if siren==.
save $data/quality_champ.dta, replace
	

		***Firm-level info from the BRN

use $base/brn_quality.dta, clear
keep siren year	employees wage_bill capital
drop if year<1997
drop if employees==0
duplicates drop
duplicates tag siren year, gen(dupl)
drop if dupl==1 & capital==0
duplicates drop siren year , force
save $data/brn_clean.dta, replace
		
				
