

use $data/export_ready.dta, clear

bys siren iso3 cn8plus id_spell: egen count_obs=count(year)
drop if count_obs==1

gen log_price=log(export/qty)
gen log_qty=log(qty)

egen iso_g=group(iso3)
egen cn8_g=group(cn8plus)

egen id_panel=group(siren iso3 cn8plus)
egen siren_year=group(siren year)

bys id_panel id_spell: egen min_year_spell=min(year)


			***Merge with instruments

merge m:1 siren year min_year_spell using $data/instru_w0s.dta, keepusing(rer_dev_w0s)
drop if _merge==2
drop _merge


			***Average gdp of the destination/origin countries

merge m:1 siren year using $data/gdp_controls.dta
drop if _merge==2
drop _merge

bys id_panel id_spell: egen mean_gdp_w_i=mean(gdp_w_import)
replace mean_gdp_w_i=0 if mean_gdp_w_i==.
replace gdp_w_import=mean_gdp_w_i if gdp_w_import==.
drop mean_gdp_w_i

bys id_panel id_spell: egen mean_gdp_w_i=mean(gdp_w_export)
replace mean_gdp_w_i=0 if mean_gdp_w_i==.
replace gdp_w_export=mean_gdp_w_i if gdp_w_export==.
drop mean_gdp_w_i


			***Info about entry

merge 1:1 siren cn8plus iso3 year using $data/entry.dta
drop if _merge==2
drop _merge


			***Bring cost shares (average from 1997-2007)


merge m:1 siren using $data/import_ratio_brn.dta, keepusing(ratio_costs)
replace ratio_costs=0 if _merge==1
drop if _merge==2
drop _merge

drop if ratio_costs==.

foreach i of var rer_dev_w0s {
replace `i'=0 if `i'==.
replace `i'=`i'*ratio_costs
}


gen beta_1=.
gen ci1_1=.
gen ci2_1=.

forvalues i=2/14 {

reghdfe log_qty  entry gdp_w_import gdp_w_export rer_dev_w0s if count_obs>=`i', absorb(id_spell#siren#iso_g#cn8plus iso_g#cn8plus#year, tol(1e-4))  cluster(siren)

replace beta_1=_b[rer_dev_w0s] if count_obs==`i'
replace ci1_1=beta_1+1.96*_se[rer_dev_w0sn] if count_obs==`i'
replace ci2_1=beta_1-1.96*_se[rer_dev_w0sn] if count_obs==`i'


}


keep count_obs beta_1 ci1_1 ci2_1 
duplicates drop

tw (rcap  ci1_1 ci2_1 count_obs ,lwidth(medthick) lcolor(black)) ///
	(scatter beta_1 count_obs ,  msize(large) ), ///
	xlabel(2(1)14) xtitle("Minimum length of the exporting spell (in years)") ///
	ytitle("Reduced-form effect") legend( order(2 "Point estimate" 1 "95% CI")) 

graph export $graphs/rf_by_spelllength.pdf, replace 

						
use $data/quality_estimates.dta, clear

egen cn8_g=group(cn8plus)
egen dest=group(iso3)

quietly reghdfe quality_agg, absorb(siren)
est sto r1
quietly reghdfe quality_agg, absorb(siren#cn8_g)
est sto r2
quietly reghdfe quality_agg, absorb(siren#cn8_g#dest)
est sto r3
quietly reghdfe quality_agg, absorb(siren#year)
est sto r4
quietly reghdfe quality_agg, absorb(siren#cn8_g#year)
est sto r5

esttab r1 r2 r3 r4 r5 using $tex/analysis_quality_aggsigma.tex, stat(r2) replace



						***We compare with Champagne stars
	
	
use $base/cn8_cn8plus_1997_2010.dta, clear
keep if cn8==22041011
keep cn8plus year
save $tmp/cn8plus_champ.dta, replace

	
use $data/quality_estimates.dta, clear

merge m:1 cn8plus year using $tmp/cn8plus_champ.dta
keep if _merge==3
drop _merge

merge m:1 siren using $data/quality_champ.dta
keep if _merge==3
drop _merge

reg quality_agg i.juhlin_stars, vce(cl siren) 
est sto r1
reg log_price i.juhlin_stars, vce(cl siren) 
est sto r2


esttab r1 using $tex/analysis_quality_aggsigma.tex, ///
	se starlevels(\sym{*} 0.10 \sym{**} 0.05 \sym{***} 0.01) b(a2) se(a2) scalars(N r2) append

	
	
						***Comparison with firm-level data

	
	
use $data/quality_estimates.dta, clear

merge m:1 siren year using $data/brn_clean.dta
keep if _merge==3

gen log_wage_av=log(wage_bill/employees)
gen log_empl=log(employees)
gen log_cap=log(capital)

egen siren_year=group(siren year)
egen cn8_g=group(cn8plus)
egen dest=group(iso3)


qui reg quality_agg log_wage_av, vce(cl siren_year)
est sto r1
qui reg quality_agg log_wage_av log_empl log_cap, vce(cl siren_year)
est sto r2
qui reghdfe quality_agg log_wage_av, absorb(dest cn8_g year) cluster(siren_year)
est sto r3
qui reghdfe quality_agg log_wage_av log_empl log_cap, absorb(dest cn8_g year) cluster(siren_year)
est sto r4
qui reghdfe quality_agg log_wage_av, absorb(dest#cn8_g#year) vce(cl siren_year)
est sto r5
qui reghdfe quality_agg log_wage_av log_empl log_cap, absorb(dest#cn8_g#year)cluster(siren_year)
est sto r6

esttab r1 r2 r3 r4 r5 r6 using $tex/analysis_quality_aggsigma.tex, ///
	se starlevels(\sym{*} 0.10 \sym{**} 0.05 \sym{***} 0.01) b(a2) se(a2) scalars(N r2) append



								****Correlation with quality ladders


use $data/quality_ladder_estimates.dta, clear


merge m:1 cn8plus using $data/hs6_cn8plus.dta
keep if _merge==3
drop _merge

merge m:1 hs6 using $data/ladder_Khandelwal_hs6.dta
keep if _merge==3
drop if ladder_quality_agg==0 | ladder_Khandelwal==0
egen dest=group(iso3)


qui reghdfe ladder_quality_agg ladder_Khandelwal, absorb(year dest) vce(cl hs6) tol(1e-4)
est sto r1
qui reghdfe ladder_quality_agg ladder_Khandelwal, absorb(dest#year) vce(cl hs6) tol(1e-4)
est sto r2
qui reghdfe ladder_quality_agg ladder_Khandelwal if n_obs>5, absorb(year dest) vce(cl hs6) tol(1e-4)
est sto r3
qui reghdfe ladder_quality_agg ladder_Khandelwal if n_obs>5, absorb(dest#year) vce(cl hs6) tol(1e-4)
est sto r4
qui reghdfe ladder_quality_agg ladder_Khandelwal if n_obs>20, absorb(year dest) vce(cl hs6) tol(1e-4)
est sto r5
qui reghdfe ladder_quality_agg ladder_Khandelwal if n_obs>20, absorb(dest#year) vce(cl hs6) tol(1e-4)
est sto r6


esttab r1 r2 r3 r4 r5 r6 using $tex/analysis_quality_aggsigma.tex, ///
	se starlevels(\sym{*} 0.10 \sym{**} 0.05 \sym{***} 0.01) b(a2) se(a2) scalars(N r2) append


	

								***Comparing quality with prices

	
use $data/quality_estimates.dta, clear
  
merge m:1 cn8plus year iso3 using $data/quality_ladder_estimates.dta
keep if _merge==3
drop _merge


egen ladder_norm=std(ladder_quality_agg)

bys iso3 cn8plus year: egen price_se=sd(log_price)
bys iso3 cn8plus year: egen price_mean=mean(log_price)

bys iso3 cn8plus year: egen quality_se=sd(quality_agg)

gen log_price_norm=(log_price-price_mean)/price_se
gen quality_norm=quality_agg/quality_se

gen quality_x_ladder=quality_norm*ladder_norm


egen market=group(iso3 cn8plus year)
egen dest=group(iso3)
egen cn8_g=group(cn8plus)

qui reghdfe log_price_norm quality_norm quality_x_ladder, absorb(dest#cn8_g#year) cluster(market) tol(1e-4)
est sto r1
qui reghdfe log_price_norm quality_norm quality_x_ladder, absorb(dest#cn8_g#year dest#cn8_g#siren) cluster(market) tol(1e-4)
est sto r2
qui reghdfe log_price_norm quality_norm quality_x_ladder if n_obs>5, absorb(dest#cn8_g#year) cluster(market) tol(1e-4)
est sto r3
qui reghdfe log_price_norm quality_norm quality_x_ladder if n_obs>5, absorb(dest#cn8_g#year dest#cn8_g#siren) cluster(market) tol(1e-4)
est sto r4
qui reghdfe log_price_norm quality_norm quality_x_ladder if n_obs>20, absorb(dest#cn8_g#year) cluster(market) tol(1e-4)
est sto r5
qui reghdfe log_price_norm quality_norm quality_x_ladder if n_obs>20, absorb(dest#cn8_g#year dest#cn8_g#siren) cluster(market) tol(1e-4)
est sto r6



esttab r1 r2 r3 r4 r5 r6 using $tex/analysis_quality_aggsigma.tex, ///
	se starlevels(\sym{*} 0.10 \sym{**} 0.05 \sym{***} 0.01) b(a2) se(a2) scalars(N r2) append



								***Comparison with number of destinations

								
use $data/quality_estimates.dta, clear

bys siren cn8plus year: egen n_dest=count(year)
bys siren iso3 year: egen n_prod=count(year)
gen log_n_dest=log(n_dest)
gen log_n_prod=log(n_prod)

egen siren_year=group(siren year)
egen cn8_g=group(cn8plus)
egen dest=group(iso3)


egen id_panel=group(siren dest cn8plus)
xtset id_panel year

qui reghdfe quality_agg log_n_dest, absorb(dest#cn8_g#year siren#dest#cn8_g) vce(cl siren_year) tol(1e-4)
est sto r1
qui reghdfe d.quality_agg d.log_n_dest, absorb(dest#cn8_g#year) cluster(siren_year) tol(1e-4)
est sto r2
qui reghdfe log_price log_n_dest, absorb(dest#cn8_g#year siren#dest#cn8_g) vce(cl siren_year) tol(1e-4)
est sto r3
qui reghdfe d.log_price d.log_n_dest, absorb(dest#cn8_g#year) cluster(siren_year) tol(1e-4)
est sto r4

qui reghdfe quality_agg log_n_prod, absorb(dest#cn8_g#year siren#dest#cn8_g) vce(cl siren_year) tol(1e-4)
est sto r5
qui reghdfe d.quality_agg d.log_n_prod, absorb(dest#cn8_g#year) cluster(siren_year) tol(1e-4)
est sto r6
qui reghdfe log_price log_n_prod, absorb(dest#cn8_g#year siren#dest#cn8_g) vce(cl siren_year) tol(1e-4)
est sto r7
qui reghdfe d.log_price d.log_n_prod, absorb(dest#cn8_g#year) cluster(siren_year) tol(1e-4)
est sto r8


esttab r1 r2 r3 r4 using $tex/analysis_quality_aggsigma.tex, ///
	se starlevels(\sym{*} 0.10 \sym{**} 0.05 \sym{***} 0.01) b(a2) se(a2) scalars(N r2) append

esttab r5 r6 r7 r8 using $tex/analysis_quality_aggsigma.tex, ///
	se starlevels(\sym{*} 0.10 \sym{**} 0.05 \sym{***} 0.01) b(a2) se(a2) scalars(N r2) append



