
use $data/estimates_sigma.dta, clear

merge 1:1 product using $data/Anson_hs1.dta
drop _merge

merge 1:1 product using $data/sutton_hs1.dta
drop _merge

merge 1:1 product using $data/se_bootstrap.dta
drop _merge
gen precision_sigma_SFS=1/se_bootstrap_sigma_rer_dev_w0sn



pwcorr sigma_SFS sigma_Anson [aw=precision_sigma_SFS], sig
matrix B=r(C)
global corr : di %3.2f B[2,1]

tw (scatter sigma_SFS sigma_Anson [aw=precision_sigma_SFS], msymbol(Oh)) (lfit sigma_SFS sigma_Anson [aw=precision_sigma_SFS]), ///
   title("`sigma'")  ytitle("Estimated price elasticity" ,size(*0.9)) xtitle("Soderbery / Broda-Weinstein's estimates" ,size(*0.9)) ///
   legend(order(1 "Estimates" 2 "Linear fit") size(*0.9)) note("Correlation = ${corr}", ring(0) position(10))

graph export $graphs/scatter_sigma_Anson.pdf, replace

		
pwcorr sigma_SFS sutton [aw=precision_sigma_SFS], sig
matrix B=r(C)
global corr : di %3.2f B[2,1]

tw (scatter sigma_SFS sutton [aw=precision_sigma_SFS], msymbol(Oh)) (lfit sigma_SFS sutton [aw=precision_sigma_SFS]), ///
   title("`sigma'")  ytitle("Estimated price elasticity" ,size(*0.9)) xtitle("Sutton's Measure of Differentiation" ,size(*0.9)) ///
   legend(order(1 "Estimates" 2 "Linear fit") size(*0.9)) note("Correlation = ${corr}", ring(0) position(2))

graph export $graphs/scatter_sigma_sutton.pdf, replace

						
use $data/quality_estimates.dta, clear

egen cn8_g=group(cn8plus)
egen dest=group(iso3)

quietly reghdfe quality_SFS, absorb(siren)
est sto r1
quietly reghdfe quality_SFS, absorb(siren#cn8_g)
est sto r2
quietly reghdfe quality_SFS, absorb(siren#cn8_g#dest)
est sto r3
quietly reghdfe quality_SFS, absorb(siren#year)
est sto r4
quietly reghdfe quality_SFS, absorb(siren#cn8_g#year)
est sto r5


esttab r1 r2 r3 r4 r5 using $tex/analysis_quality.tex, stat(r2) replace



						***We compare with Champagne stars
	
	
use $base/cn8_cn8plus_1997_2010.dta, clear
keep if cn8==22041011
keep cn8plus year
save $tmp/cn8plus_champ.dta, replace

	
use $data/quality_estimates.dta, clear

merge m:1 cn8plus year using $tmp/cn8plus_champ.dta
keep if _merge==3
drop _merge

merge m:1 siren using $data/quality_champ.dta
keep if _merge==3
drop _merge

reg quality_SFS i.juhlin_stars, vce(cl siren) 
est sto r1

esttab r1 using $tex/analysis_quality.tex, ///
	se starlevels(\sym{*} 0.10 \sym{**} 0.05 \sym{***} 0.01) b(a2) se(a2) scalars(N r2) append

	
	
						***Comparison with firm-level data

	
	
use $data/quality_estimates.dta, clear

merge m:1 siren year using $data/brn_clean.dta
keep if _merge==3

gen log_wage_av=log(wage_bill/employees)
gen log_empl=log(employees)
gen log_cap=log(capital)

egen siren_year=group(siren year)
egen cn8_g=group(cn8plus)
egen dest=group(iso3)


qui reg quality_SFS log_wage_av, vce(cl siren_year)
est sto r1
qui reg quality_SFS log_wage_av log_empl log_cap, vce(cl siren_year)
est sto r2
qui reghdfe quality_SFS log_wage_av, absorb(dest cn8_g year) cluster(siren_year)
est sto r3
qui reghdfe quality_SFS log_wage_av log_empl log_cap, absorb(dest cn8_g year) cluster(siren_year)
est sto r4
qui reghdfe quality_SFS log_wage_av, absorb(dest#cn8_g#year) vce(cl siren_year)
est sto r5
qui reghdfe quality_SFS log_wage_av log_empl log_cap, absorb(dest#cn8_g#year)cluster(siren_year)
est sto r6

esttab r1 r2 r3 r4 r5 r6 using $tex/analysis_quality.tex, ///
	se starlevels(\sym{*} 0.10 \sym{**} 0.05 \sym{***} 0.01) b(a2) se(a2) scalars(N r2) append



								****Correlation with quality ladders


use $data/quality_ladder_estimates.dta, clear


merge m:1 cn8plus using $data/hs6_cn8plus.dta
keep if _merge==3
drop _merge

merge m:1 hs6 using $data/ladder_Khandelwal_hs6.dta
keep if _merge==3
drop if ladder_quality_SFS==0 | ladder_Khandelwal==0
egen dest=group(iso3)


qui reghdfe ladder_quality_SFS ladder_Khandelwal, absorb(year dest) vce(cl hs6) tol(1e-4)
est sto r1
qui reghdfe ladder_quality_SFS ladder_Khandelwal, absorb(dest#year) vce(cl hs6) tol(1e-4)
est sto r2
qui reghdfe ladder_quality_SFS ladder_Khandelwal if n_obs>5, absorb(year dest) vce(cl hs6) tol(1e-4)
est sto r3
qui reghdfe ladder_quality_SFS ladder_Khandelwal if n_obs>5, absorb(dest#year) vce(cl hs6) tol(1e-4)
est sto r4
qui reghdfe ladder_quality_SFS ladder_Khandelwal if n_obs>20, absorb(year dest) vce(cl hs6) tol(1e-4)
est sto r5
qui reghdfe ladder_quality_SFS ladder_Khandelwal if n_obs>20, absorb(dest#year) vce(cl hs6) tol(1e-4)
est sto r6

esttab r1 r2 r3 r4 r5 r6 using $tex/analysis_quality.tex, ///
	se starlevels(\sym{*} 0.10 \sym{**} 0.05 \sym{***} 0.01) b(a2) se(a2) scalars(N r2) append


	

								***Comparing quality with prices

	
use $data/quality_estimates.dta, clear
  
merge m:1 cn8plus year iso3 using $data/quality_ladder_estimates.dta
keep if _merge==3
drop _merge


egen ladder_norm=std(ladder_quality_SFS)

bys iso3 cn8plus year: egen price_se=sd(log_price)
bys iso3 cn8plus year: egen price_mean=mean(log_price)

bys iso3 cn8plus year: egen quality_se=sd(quality_SFS)

gen log_price_norm=(log_price-price_mean)/price_se
gen quality_norm=quality_SFS/quality_se

gen quality_x_ladder=quality_norm*ladder_norm


egen market=group(iso3 cn8plus year)
egen dest=group(iso3)
egen cn8_g=group(cn8plus)

qui reghdfe log_price_norm quality_norm quality_x_ladder, absorb(dest#cn8_g#year) cluster(market) tol(1e-4)
est sto r1
qui reghdfe log_price_norm quality_norm quality_x_ladder, absorb(dest#cn8_g#year dest#cn8_g#siren) cluster(market) tol(1e-4)
est sto r2
qui reghdfe log_price_norm quality_norm quality_x_ladder if n_obs>5, absorb(dest#cn8_g#year) cluster(market) tol(1e-4)
est sto r3
qui reghdfe log_price_norm quality_norm quality_x_ladder if n_obs>5, absorb(dest#cn8_g#year dest#cn8_g#siren) cluster(market) tol(1e-4)
est sto r4
qui reghdfe log_price_norm quality_norm quality_x_ladder if n_obs>20, absorb(dest#cn8_g#year) cluster(market) tol(1e-4)
est sto r5
qui reghdfe log_price_norm quality_norm quality_x_ladder if n_obs>20, absorb(dest#cn8_g#year dest#cn8_g#siren) cluster(market) tol(1e-4)
est sto r6

esttab r1 r2 r3 r4 r5 r6 using $tex/analysis_quality.tex, ///
	se starlevels(\sym{*} 0.10 \sym{**} 0.05 \sym{***} 0.01) b(a2) se(a2) scalars(N r2) append



								***Comparison with number of destinations

								
use $data/quality_estimates.dta, clear

bys siren cn8plus year: egen n_dest=count(year)
bys siren iso3 year: egen n_prod=count(year)
gen log_n_dest=log(n_dest)
gen log_n_prod=log(n_prod)

egen siren_year=group(siren year)
egen cn8_g=group(cn8plus)
egen dest=group(iso3)


egen id_panel=group(siren dest cn8plus)
xtset id_panel year

qui reghdfe quality_SFS log_n_dest, absorb(dest#cn8_g#year siren#dest#cn8_g) vce(cl siren_year) tol(1e-4)
est sto r1
qui reghdfe d.quality_SFS d.log_n_dest, absorb(dest#cn8_g#year) cluster(siren_year) tol(1e-4)
est sto r2
qui reghdfe log_price log_n_dest, absorb(dest#cn8_g#year siren#dest#cn8_g) vce(cl siren_year) tol(1e-4)
est sto r3
qui reghdfe d.log_price d.log_n_dest, absorb(dest#cn8_g#year) cluster(siren_year) tol(1e-4)
est sto r4

qui reghdfe quality_SFS log_n_prod, absorb(dest#cn8_g#year siren#dest#cn8_g) vce(cl siren_year) tol(1e-4)
est sto r5
qui reghdfe d.quality_SFS d.log_n_prod, absorb(dest#cn8_g#year) cluster(siren_year) tol(1e-4)
est sto r6
qui reghdfe log_price log_n_prod, absorb(dest#cn8_g#year siren#dest#cn8_g) vce(cl siren_year) tol(1e-4)
est sto r7
qui reghdfe d.log_price d.log_n_prod, absorb(dest#cn8_g#year) cluster(siren_year) tol(1e-4)
est sto r8

esttab r1 r2 r3 r4 using $tex/analysis_quality.tex, ///
	se starlevels(\sym{*} 0.10 \sym{**} 0.05 \sym{***} 0.01) b(a2) se(a2) scalars(N r2) append

esttab r5 r6 r7 r8 using $tex/analysis_quality.tex, ///
	se starlevels(\sym{*} 0.10 \sym{**} 0.05 \sym{***} 0.01) b(a2) se(a2) scalars(N r2) append



